@@ -46,7 +46,7 @@ BEGIN {
 		      dep14_version_mangle
                       debiantags debiantag_new
 		      debiantag_maintview
-		      upstreamversion
+		      upstreamversion is_native
 		      upstream_commitish_search resolve_upstream_version
 		      stripepoch source_file_leafname is_orig_file_of_p_v
 		      server_branch server_ref
@@ -211,6 +211,18 @@ sub upstreamversion ($) {
     return $vsn;
 }
 
+sub is_native ($) {
+    # Dpkg::Version->is_native emits an unjustifiedly polemical warning
+    # in forky.
+    #   https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1123630
+    # Reimplement it.  (This also works on unblessed string scalars.)
+    #
+    # There are replacement methods but they aren't available in older
+    # release; or we could override the deprecation warning.  This is easiest.
+    my ($vsn) = @_;
+    !!("$vsn" !~ m/-/)
+}
+
 sub source_file_leafname ($$$) {
     my ($package,$vsn,$sfx) = @_;
     return "${package}_".(stripepoch $vsn).$sfx
